%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
% Funktion        : Umformen von physikalischen Größen in ein Befehl      %
%                   für den UR10 --> Für Bewegungsbefehl movej            %
%                                                                         %
%                                                                         %
% Eingabe         : q: Soll-Winkel in einem 1x6 Vektor                    %
%                   a: Winkelbeschleunigung der Gelenke in rad/s^2        %
%                   v: Winkelgeschwindigkeit der Gelenke in rad/s         %
%                   t: Zeitangabe, wie lange die Bewegung braucht         %
%                   --> hat Prio vor a und v (wird nicht benötigt t=0)    %
%                   r: Übergangsradius in m (wir nicht benötigt r=0)      %
%                                                                         %
%                                                                         %
% Ausgabe         : commandString: String des Befehls                     %
%                                                                         %
%                                                                         %
% Autor           : Kevin Penner                                          %
%                                                                         %
% Implementation  : MATLAB R2016b                                         %
%                                                                         %
% Bemerkung       :                                                       %
%                                                                         %
% Änderungsdatum  : 03.05.2017                                            %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [commandString] = command2string(q,a,v,t,r)
    
    commandString = ['movej([' num2str(q(1)) ', ' num2str(q(2)) ', ' num2str(q(3)) ', ' num2str(q(4))...
                    ', ' num2str(q(5)) ', ' num2str(q(6)) '], ' num2str(a) ', ' num2str(v) ', ' num2str(t)...
                    ', ' num2str(r) ')'];

end